package com.muyu.product.domain;

import com.muyu.common.core.annotation.Excel;
import com.muyu.common.core.web.domain.TreeEntity;
import com.muyu.product.domain.model.CategoryInfoSaveModel;
import com.muyu.product.domain.req.CategoryReq;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

/**
 * 品类信息对象 category_info
 *
 * @author Saisai
 * @date 2024-02-29
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
public class CategoryInfo extends TreeEntity
{
    private static final long serialVersionUID = 1L;

    /** 主键 */
    private Long id;

    /** 品类名称 */
    @Excel(name = "品类名称")
    private String name;

    /** 图片 */
    @Excel(name = "图片")
    private String image;

    /** 是否启用 */
    @Excel(name = "是否启用")
    private String status;

    /**
     * 查询构造器
     * @param req
     * @return
     */
    public static CategoryInfo queryBuilder(CategoryReq req){
        return CategoryInfo.builder()
                .name(req.getName())
                .image(req.getImage())
                .status(req.getStatus())
                .remark(req.getRemark())
                .build();
    }


    /** 响应值对象 */
    public static CategoryInfo saveCategoryBuilder(CategoryInfoSaveModel req){
        return CategoryInfo.builder()
                .name(req.getName())
                .status(req.getStatus())
                .image(req.getImage())
                .remark(req.getRemark())
                .createBy(req.getCreateBy())
                .createTime(req.getCreateTime())
                .build();
    }
}
