package com.muyu.product.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.muyu.product.domain.Attribute;
import com.muyu.product.domain.req.AttributeGroupReq;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.product.domain.AttributeGroup;
import com.muyu.product.service.IAttributeGroupService;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 属性组Controller
 *
 * @author muyu
 * @date 2024-02-29
 */
@RestController
@RequestMapping("/group")
public class AttributeGroupController extends BaseController
{
    @Autowired
    private IAttributeGroupService attributeGroupService;

    /**
     * 查询属性组列表
     */
    @RequiresPermissions("product:group:list")
    @GetMapping("/list")
    public Result<TableDataInfo<AttributeGroup>> list(AttributeGroup attributeGroup)
    {
        startPage();
        List<AttributeGroup> list = attributeGroupService.selectAttributeGroupList(attributeGroup);
        return getDataTable(list);
    }

    /**
     * 导出属性组列表
     */
    @RequiresPermissions("product:group:export")
    @Log(title = "属性组", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AttributeGroup attributeGroup)
    {
        List<AttributeGroup> list = attributeGroupService.selectAttributeGroupList(attributeGroup);
        ExcelUtil<AttributeGroup> util = new ExcelUtil<AttributeGroup>(AttributeGroup.class);
        util.exportExcel(response, list, "属性组数据");
    }

    /**
     * 获取属性组详细信息
     */
    @RequiresPermissions("product:group:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(attributeGroupService.selectAttributeGroupById(id));
    }

    /**
     * 新增属性组
     */
    @RequiresPermissions("product:group:add")
    @Log(title = "属性组", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody AttributeGroupReq attributeGroupReq)
    {
        return toAjax(attributeGroupService.insertAttributeGroup(attributeGroupReq));
    }

    /**
     * 修改属性组
     */
    @RequiresPermissions("product:group:edit")
    @Log(title = "属性组", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody AttributeGroupReq attributeGroupReq)
    {
        return toAjax(attributeGroupService.updateAttributeGroup(attributeGroupReq));
    }

    /**
     * 删除属性组
     */
    @RequiresPermissions("product:group:remove")
    @Log(title = "属性组", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(attributeGroupService.deleteAttributeGroupByIds(ids));
    }
}
