package com.muyu.product.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.utils.DateUtils;
import com.muyu.product.domain.CategoryAttribute;
import com.muyu.product.domain.CategoryAttributeGroup;
import com.muyu.product.domain.model.CategoryInfoSaveModel;
import com.muyu.product.service.ICategoryAttributeService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.muyu.product.mapper.CategoryInfoMapper;
import com.muyu.product.domain.CategoryInfo;
import com.muyu.product.service.ICategoryInfoService;

/**
 * 品类信息Service业务层处理
 *
 * @author Saisai
 * @date 2024-02-29
 */
@Slf4j
@Service
public class CategoryInfoServiceImpl extends ServiceImpl<CategoryInfoMapper,CategoryInfo> implements ICategoryInfoService
{
    @Autowired
    private CategoryInfoMapper categoryInfoMapper;
    @Autowired
    private ICategoryAttributeService categoryAttributeService;
    @Autowired
    private CategoryAttributeGroupServiceImpl categoryAttributeGroupService;

    /**
     * 查询品类信息
     *
     * @param id 品类信息主键
     * @return 品类信息
     */
    @Override
    public CategoryInfo selectCategoryInfoById(Long id)
    {
        return categoryInfoMapper.selectCategoryInfoById(id);
    }

    /**
     * 查询品类信息列表
     *
     * @param categoryInfo 品类信息
     * @return 品类信息
     */
    @Override
    public List<CategoryInfo> selectCategoryInfoList(CategoryInfo categoryInfo)
    {
        return categoryInfoMapper.selectCategoryInfoList(categoryInfo);
    }

    /**
     * 新增品类信息
     *
     * @param categoryInfo 品类信息
     * @return 结果
     */
    @Override
    public int insertCategoryInfo(CategoryInfo categoryInfo)
    {
        categoryInfo.setCreateTime(DateUtils.getNowDate());
        return categoryInfoMapper.insertCategoryInfo(categoryInfo);
    }

    /**
     * 修改品类信息
     *
     * @param categoryInfo 品类信息
     * @return 结果
     */
    @Override
    public int updateCategoryInfo(CategoryInfo categoryInfo)
    {
        categoryInfo.setUpdateTime(DateUtils.getNowDate());
        return categoryInfoMapper.updateCategoryInfo(categoryInfo);
    }

    /**
     * 批量删除品类信息
     *
     * @param ids 需要删除的品类信息主键
     * @return 结果
     */
    @Override
    public int deleteCategoryInfoByIds(Long[] ids)
    {
        return categoryInfoMapper.deleteCategoryInfoByIds(ids);
    }

    /**
     * 删除品类信息信息
     *
     * @param id 品类信息主键
     * @return 结果
     */
    @Override
    public int deleteCategoryInfoById(Long id)
    {
        return categoryInfoMapper.deleteCategoryInfoById(id);
    }

    @Override
    public boolean save(CategoryInfoSaveModel categoryInfoSaveModel) {
        //通过品类信息构建体构建品类对象
        CategoryInfo categoryInfo = CategoryInfo.saveCategoryBuilder(categoryInfoSaveModel);
        //调用重载方法
        boolean save = this.save(categoryInfo);
        //获取当前品类主键
        Long id = categoryInfo.getId();
        //获取已选属性主键集
        List<Long> checkedAttributeIds = categoryInfoSaveModel.getCheckedAttributeIds();
        //判断已选属性集是否为空
        if (checkedAttributeIds != null && !checkedAttributeIds.isEmpty()){
            categoryAttributeService.saveBatch(
                    checkedAttributeIds.stream()
                            .map(attributeId -> CategoryAttribute.categoryBuilder(id,attributeId)).toList()
            );
        }
        List<Long> attributeGroupIds = categoryInfoSaveModel.getAttributeGroupIds();
        if (attributeGroupIds != null && !attributeGroupIds.isEmpty()){
            categoryAttributeGroupService.saveBatch(
                    attributeGroupIds.stream().
                            map(groupId -> CategoryAttributeGroup.saveBuilder(id,groupId)).toList()
            );
        }
        return save;
    }
}
