package com.muyu.product.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.utils.DateUtils;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.product.domain.Rule;
import com.muyu.product.domain.RuleAttr;
import com.muyu.product.domain.model.RuleAttrAddModel;
import com.muyu.product.domain.req.RuleAttrReq;
import com.muyu.product.domain.resp.RuleAttrResp;
import com.muyu.product.mapper.RuleMapper;
import com.muyu.product.service.IRuleService;
import com.muyu.product.service.RuleAttrService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;
import java.util.function.Function;

/**
 * 规格Service业务层处理
 *
 * @author saisai
 * @date 2024-02-29
 */
@Service
public class RuleServiceImpl extends ServiceImpl<RuleMapper, Rule> implements IRuleService {
    @Autowired
    private RuleMapper ruleMapper;
    private RuleAttrService ruleAttrService;

    @Autowired
    public RuleServiceImpl(RuleAttrService ruleAttrService) {
        this.ruleAttrService = ruleAttrService;
    }

    /**
     * 查询规格
     *
     * @param id 规格主键
     * @return 规格
     */
    @Override
    public RuleAttrResp selectRuleById(Long id) {
        Rule byId = this.getById(id);
        return RuleAttrResp.saveBuilder(byId, new Function<Long, List<RuleAttrAddModel>>() {
            @Override
            public List<RuleAttrAddModel> apply(Long id) {
                LambdaQueryWrapper<RuleAttr> wrapper = new LambdaQueryWrapper<>();
                List<RuleAttr> list = ruleAttrService.list(wrapper.eq(RuleAttr::getRuleId, id));
                return RuleAttrAddModel.saveBuilder(list);
            }
        });
//        return RuleAttrResp.saveBuilder(ruleMapper.selectRuleById(id), null);
    }

    /**
     * 查询规格列表
     *
     * @param rule 规格
     * @return 规格
     */
    @Override
    public List<Rule> selectRuleList(Rule rule) {
        return ruleMapper.selectRuleList(rule);
    }

    /**
     * 新增规格
     *
     * @param ruleAttrReq 规格
     * @return 结果
     */
    @Override
    @Transactional
    public int insertRule(RuleAttrReq ruleAttrReq) {
        Rule rule = Rule.saveBuilder(ruleAttrReq, SecurityUtils::getUsername);
        int i = ruleMapper.insertRule(rule);
        ruleAttrService.saveBatch(RuleAttr.saveBuilder(ruleAttrReq, SecurityUtils::getUsername));
        return i;
    }

    /**
     * 修改规格
     *
     * @param ruleAttrReq 规格
     * @return 结果
     */
    @Override
    @Transactional
    public int updateRule(RuleAttrReq ruleAttrReq) {

        //获取当前规格对象
        Rule rule = Rule.updateBuilder(ruleAttrReq);
        LambdaQueryWrapper<RuleAttr> wrapper = new LambdaQueryWrapper<>();
        //查找当前规格属性
//        List<Long> longs = ruleAttrService.list(wrapper.eq(RuleAttr::getRuleId, rule.getId())).stream().map(RuleAttr::getId).toList();
        ruleAttrService.remove(wrapper.eq(RuleAttr::getRuleId, rule.getId()));
//        ruleAttrService.removeBatchByIds(longs);
        ruleAttrService.saveBatch(RuleAttr.saveBuilder(ruleAttrReq, SecurityUtils::getUsername));
        return ruleMapper.updateRule(rule);
    }

    /**
     * 批量删除规格
     *
     * @param ids 需要删除的规格主键
     * @return 结果
     */
    @Override
    public int deleteRuleByIds(Long[] ids) {
        return ruleMapper.deleteRuleByIds(ids);
    }

    /**
     * 删除规格信息
     *
     * @param id 规格主键
     * @return 结果
     */
    @Override
    public int deleteRuleById(Long id) {
        LambdaQueryWrapper<Rule> queryWrapper = new LambdaQueryWrapper<>();
        Rule byId = this.getById(queryWrapper.eq(Rule::getId, id));
        LambdaQueryWrapper<RuleAttr> wrapper = new LambdaQueryWrapper<>();
        ruleAttrService.remove(wrapper.eq(RuleAttr::getRuleId, byId.getId()));
        return ruleMapper.deleteRuleById(id);
    }

    @Override
    public List<RuleAttrResp> selectRuleAttrList(RuleAttrReq ruleAttrReq) {
        //规格集合
        List<Rule> rules = this.selectRuleList(Rule.saveBuilder(ruleAttrReq, SecurityUtils::getUsername));
        return rules.stream().map(rule ->
                RuleAttrResp.saveBuilder(rule, id -> {
                    LambdaQueryWrapper<RuleAttr> wrapper = new LambdaQueryWrapper<>();
                    List<RuleAttr> list = ruleAttrService.list(wrapper.eq(RuleAttr::getRuleId, rule.getId()));
                    return RuleAttrAddModel.saveBuilder(list);
                })
        ).toList();
    }
}
